[Scummvm-git-logs] scummvm master -> f59fdb5571eaf406af3b91da75a38a220652f1f0

bluegr noreply at scummvm.org
Sun Apr 26 18:47:26 UTC 2026


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://api.github.com/repos/scummvm/scummvm .

Summary:
f59fdb5571 NANCY: Fix lathe puzzle sounds


Commit: f59fdb5571eaf406af3b91da75a38a220652f1f0
    https://github.com/scummvm/scummvm/commit/f59fdb5571eaf406af3b91da75a38a220652f1f0
Author: tunnelsociety (tunnelsociety at mm.st)
Date: 2026-04-26T21:47:21+03:00

Commit Message:
NANCY: Fix lathe puzzle sounds

Lathe move-left-right and depth-adjust sounds were swapped

Changed paths:
    engines/nancy/action/puzzle/cuttingpuzzle.cpp
    engines/nancy/action/puzzle/cuttingpuzzle.h


diff --git a/engines/nancy/action/puzzle/cuttingpuzzle.cpp b/engines/nancy/action/puzzle/cuttingpuzzle.cpp
index ddf0162a3c3..8c41ab388a7 100644
--- a/engines/nancy/action/puzzle/cuttingpuzzle.cpp
+++ b/engines/nancy/action/puzzle/cuttingpuzzle.cpp
@@ -67,9 +67,9 @@ void CuttingPuzzle::readData(Common::SeekableReadStream &stream) {
 		_correctGrooves[i] = stream.readSint16LE();  // +0x3cc..0x3db
 
 	_latheSound.readNormal(stream);                  // +0x3dc (49 bytes)
-	_clickSound.readNormal(stream);                  // +0x40d (49 bytes)
-	_clickSound2.readNormal(stream);                 // +0x43e (49 bytes)
-	_clickSound3.readNormal(stream);                 // +0x46f (49 bytes)
+	_moveSound.readNormal(stream);                   // +0x40d (49 bytes)
+	_startStopSound.readNormal(stream);              // +0x43e (49 bytes)
+	_depthSound.readNormal(stream);                  // +0x46f (49 bytes)
 	_cutSound.readNormal(stream);                    // +0x4a0 (49 bytes)
 
 	_puzzleSolvedScene.readData(stream);                 // +0x4d1 (25 bytes)
@@ -183,9 +183,9 @@ void CuttingPuzzle::execute() {
 		registerGraphics();
 
 		g_nancy->_sound->loadSound(_latheSound);
-		g_nancy->_sound->loadSound(_clickSound);
-		g_nancy->_sound->loadSound(_clickSound2);
-		g_nancy->_sound->loadSound(_clickSound3);
+		g_nancy->_sound->loadSound(_moveSound);
+		g_nancy->_sound->loadSound(_startStopSound);
+		g_nancy->_sound->loadSound(_depthSound);
 		g_nancy->_sound->loadSound(_cutSound);
 
 		_state = kRun;
@@ -307,9 +307,9 @@ void CuttingPuzzle::execute() {
 		// Stop all sounds.
 		g_nancy->_sound->stopSound(_latheSound);
 		g_nancy->_sound->stopSound(_cutSound);
-		g_nancy->_sound->stopSound(_clickSound);
-		g_nancy->_sound->stopSound(_clickSound2);
-		g_nancy->_sound->stopSound(_clickSound3);
+		g_nancy->_sound->stopSound(_moveSound);
+		g_nancy->_sound->stopSound(_startStopSound);
+		g_nancy->_sound->stopSound(_depthSound);
 
 		if (_cancelled) {
 			// Player explicitly cancelled: go to the cancel scene and possibly set
@@ -369,7 +369,7 @@ void CuttingPuzzle::handleInput(NancyInput &input) {
 				_currentLeverDepth = (_currentLeverDepth == 0) ? 3 : _currentLeverDepth - 1;
 			else
 				_currentLeverDepth = (_currentLeverDepth + 1) % 4;
-			g_nancy->_sound->playSound(_clickSound);
+			g_nancy->_sound->playSound(_depthSound);
 			redrawSurface();
 		}
 		return;
@@ -384,7 +384,7 @@ void CuttingPuzzle::handleInput(NancyInput &input) {
 			_latheRunning    = true;
 			_macroCycleCount = 0;
 			_animFrame       = 0;
-			g_nancy->_sound->playSound(_clickSound2);
+			g_nancy->_sound->playSound(_startStopSound);
 			redrawSurface();
 		}
 		return;
@@ -401,14 +401,14 @@ void CuttingPuzzle::handleInput(NancyInput &input) {
 			g_nancy->_cursor->setCursorType(CursorManager::kMoveLeft);
 			if (input.input & NancyInput::kLeftMouseButtonUp) {
 				--_currentMarkerPos;
-				g_nancy->_sound->playSound(_clickSound3);
+				g_nancy->_sound->playSound(_moveSound);
 				redrawSurface();
 			}
 		} else if (!goLeft && _currentMarkerPos + 1 < _numGrooves) {
 			g_nancy->_cursor->setCursorType(CursorManager::kMoveRight);
 			if (input.input & NancyInput::kLeftMouseButtonUp) {
 				++_currentMarkerPos;
-				g_nancy->_sound->playSound(_clickSound3);
+				g_nancy->_sound->playSound(_moveSound);
 				redrawSurface();
 			}
 		}
diff --git a/engines/nancy/action/puzzle/cuttingpuzzle.h b/engines/nancy/action/puzzle/cuttingpuzzle.h
index 116e565eb00..541b230e6b9 100644
--- a/engines/nancy/action/puzzle/cuttingpuzzle.h
+++ b/engines/nancy/action/puzzle/cuttingpuzzle.h
@@ -98,11 +98,11 @@ protected:
 
 	Common::Array<int16> _correctGrooves;        // data+0x3cc  8 target depths (one per groove slot)
 
-	SoundDescription _latheSound;  // data+0x3dc  looping lathe running sound
-	SoundDescription _clickSound;  // data+0x40d  click sound (lever / UI)
-	SoundDescription _clickSound2; // data+0x43e  click sound 2
-	SoundDescription _clickSound3; // data+0x46f  click sound 3
-	SoundDescription _cutSound;    // data+0x4a0  groove-cutting sound
+	SoundDescription _latheSound;     // data+0x3dc  looping lathe running sound
+	SoundDescription _moveSound;      // data+0x40d  move left & right sound
+	SoundDescription _startStopSound; // data+0x43e  on/off switch sound
+	SoundDescription _depthSound;     // data+0x46f  depth adjust sound
+	SoundDescription _cutSound;       // data+0x4a0  groove-cutting sound
 
 	SceneChangeWithFlag _puzzleSolvedScene;    // data+0x4d1 (25 bytes)
 	uint16 _doneSoundDelaySecs = 0;        // data+0x4ea  wait before playing done sound (seconds)




More information about the Scummvm-git-logs mailing list